# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/cch/Documents/python/music manager/GUI.ui'
#
# Created: Thu Jul  2 15:57:03 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.setWindowModality(QtCore.Qt.NonModal)
        MainWindow.resize(898, 720)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.horizontalLayout_6 = QtGui.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.frame = QtGui.QFrame(self.centralwidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName(_fromUtf8("frame"))
        self.gridLayout_4 = QtGui.QGridLayout(self.frame)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.verticalLayout_4 = QtGui.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.verticalLayout = QtGui.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label_3 = QtGui.QLabel(self.frame)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.verticalLayout.addWidget(self.label_3)
        self.lineEditTitle = QtGui.QLineEdit(self.frame)
        self.lineEditTitle.setObjectName(_fromUtf8("lineEditTitle"))
        self.verticalLayout.addWidget(self.lineEditTitle)
        self.verticalLayout_4.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtGui.QVBoxLayout()
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.label_2 = QtGui.QLabel(self.frame)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verticalLayout_2.addWidget(self.label_2)
        self.lineEditAlbum = QtGui.QLineEdit(self.frame)
        self.lineEditAlbum.setObjectName(_fromUtf8("lineEditAlbum"))
        self.verticalLayout_2.addWidget(self.lineEditAlbum)
        self.verticalLayout_4.addLayout(self.verticalLayout_2)
        self.verticalLayout_3 = QtGui.QVBoxLayout()
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.label = QtGui.QLabel(self.frame)
        self.label.setObjectName(_fromUtf8("label"))
        self.verticalLayout_3.addWidget(self.label)
        self.lineEditInterpreter = QtGui.QLineEdit(self.frame)
        self.lineEditInterpreter.setObjectName(_fromUtf8("lineEditInterpreter"))
        self.verticalLayout_3.addWidget(self.lineEditInterpreter)
        self.verticalLayout_4.addLayout(self.verticalLayout_3)
        self.verticalLayout_9 = QtGui.QVBoxLayout()
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.label_5 = QtGui.QLabel(self.frame)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout_9.addWidget(self.label_5)
        self.lineEditComment = QtGui.QLineEdit(self.frame)
        self.lineEditComment.setObjectName(_fromUtf8("lineEditComment"))
        self.verticalLayout_9.addWidget(self.lineEditComment)
        self.verticalLayout_4.addLayout(self.verticalLayout_9)
        self.verticalLayout_5 = QtGui.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.label_4 = QtGui.QLabel(self.frame)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_5.addWidget(self.label_4)
        self.spinBoxRating = QtGui.QSpinBox(self.frame)
        self.spinBoxRating.setMinimum(1)
        self.spinBoxRating.setMaximum(20)
        self.spinBoxRating.setObjectName(_fromUtf8("spinBoxRating"))
        self.verticalLayout_5.addWidget(self.spinBoxRating)
        self.verticalLayout_4.addLayout(self.verticalLayout_5)
        self.widget_2 = QtGui.QWidget(self.frame)
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.widget_2)
        self.horizontalLayout_2.setMargin(0)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.csCheckBox = QtGui.QCheckBox(self.widget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.csCheckBox.sizePolicy().hasHeightForWidth())
        self.csCheckBox.setSizePolicy(sizePolicy)
        self.csCheckBox.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.csCheckBox.setAutoFillBackground(False)
        self.csCheckBox.setTristate(False)
        self.csCheckBox.setObjectName(_fromUtf8("csCheckBox"))
        self.horizontalLayout_2.addWidget(self.csCheckBox)
        self.verticalLayout_4.addWidget(self.widget_2)
        self.genreButton = QtGui.QPushButton(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.genreButton.sizePolicy().hasHeightForWidth())
        self.genreButton.setSizePolicy(sizePolicy)
        self.genreButton.setObjectName(_fromUtf8("genreButton"))
        self.verticalLayout_4.addWidget(self.genreButton)
        self.horizontalLayout_7 = QtGui.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.filterResetButton = QtGui.QPushButton(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filterResetButton.sizePolicy().hasHeightForWidth())
        self.filterResetButton.setSizePolicy(sizePolicy)
        self.filterResetButton.setObjectName(_fromUtf8("filterResetButton"))
        self.horizontalLayout_7.addWidget(self.filterResetButton)
        self.saveButton = QtGui.QPushButton(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.saveButton.sizePolicy().hasHeightForWidth())
        self.saveButton.setSizePolicy(sizePolicy)
        self.saveButton.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.saveButton.setObjectName(_fromUtf8("saveButton"))
        self.horizontalLayout_7.addWidget(self.saveButton)
        self.verticalLayout_4.addLayout(self.horizontalLayout_7)
        self.widget = QtGui.QWidget(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget.sizePolicy().hasHeightForWidth())
        self.widget.setSizePolicy(sizePolicy)
        self.widget.setObjectName(_fromUtf8("widget"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.widget)
        self.horizontalLayout.setMargin(0)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.verticalLayout_4.addWidget(self.widget)
        self.frame_3 = QtGui.QFrame(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy)
        self.frame_3.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_3.setObjectName(_fromUtf8("frame_3"))
        self.verticalLayout_7 = QtGui.QVBoxLayout(self.frame_3)
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.tabWidget = QtGui.QTabWidget(self.frame_3)
        self.tabWidget.setTabPosition(QtGui.QTabWidget.North)
        self.tabWidget.setUsesScrollButtons(False)
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.genretab = QtGui.QWidget()
        self.genretab.setObjectName(_fromUtf8("genretab"))
        self.gridLayout_5 = QtGui.QGridLayout(self.genretab)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.scrollGenre = QtGui.QScrollArea(self.genretab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollGenre.sizePolicy().hasHeightForWidth())
        self.scrollGenre.setSizePolicy(sizePolicy)
        self.scrollGenre.setMinimumSize(QtCore.QSize(200, 0))
        self.scrollGenre.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollGenre.setWidgetResizable(False)
        self.scrollGenre.setObjectName(_fromUtf8("scrollGenre"))
        self.genreWidget = QtGui.QWidget()
        self.genreWidget.setGeometry(QtCore.QRect(0, 0, 172, 460))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.genreWidget.sizePolicy().hasHeightForWidth())
        self.genreWidget.setSizePolicy(sizePolicy)
        self.genreWidget.setObjectName(_fromUtf8("genreWidget"))
        self.gridLayout_2 = QtGui.QGridLayout(self.genreWidget)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.genreLayout = QtGui.QFormLayout()
        self.genreLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.genreLayout.setRowWrapPolicy(QtGui.QFormLayout.DontWrapRows)
        self.genreLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.genreLayout.setObjectName(_fromUtf8("genreLayout"))
        self.gridLayout_2.addLayout(self.genreLayout, 0, 0, 1, 1)
        self.scrollGenre.setWidget(self.genreWidget)
        self.gridLayout_5.addWidget(self.scrollGenre, 0, 0, 1, 1)
        self.tabWidget.addTab(self.genretab, _fromUtf8(""))
        self.albumtab = QtGui.QWidget()
        self.albumtab.setObjectName(_fromUtf8("albumtab"))
        self.gridLayout_7 = QtGui.QGridLayout(self.albumtab)
        self.gridLayout_7.setObjectName(_fromUtf8("gridLayout_7"))
        self.scrollAlbum = QtGui.QScrollArea(self.albumtab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAlbum.sizePolicy().hasHeightForWidth())
        self.scrollAlbum.setSizePolicy(sizePolicy)
        self.scrollAlbum.setMinimumSize(QtCore.QSize(200, 0))
        self.scrollAlbum.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollAlbum.setWidgetResizable(False)
        self.scrollAlbum.setObjectName(_fromUtf8("scrollAlbum"))
        self.albumWidget = QtGui.QWidget()
        self.albumWidget.setGeometry(QtCore.QRect(0, 0, 172, 460))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.albumWidget.sizePolicy().hasHeightForWidth())
        self.albumWidget.setSizePolicy(sizePolicy)
        self.albumWidget.setObjectName(_fromUtf8("albumWidget"))
        self.gridLayout_6 = QtGui.QGridLayout(self.albumWidget)
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.albumLayout = QtGui.QFormLayout()
        self.albumLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.albumLayout.setRowWrapPolicy(QtGui.QFormLayout.DontWrapRows)
        self.albumLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.albumLayout.setObjectName(_fromUtf8("albumLayout"))
        self.gridLayout_6.addLayout(self.albumLayout, 0, 0, 1, 1)
        self.scrollAlbum.setWidget(self.albumWidget)
        self.gridLayout_7.addWidget(self.scrollAlbum, 0, 0, 1, 1)
        self.tabWidget.addTab(self.albumtab, _fromUtf8(""))
        self.interpretertab = QtGui.QWidget()
        self.interpretertab.setObjectName(_fromUtf8("interpretertab"))
        self.gridLayout_9 = QtGui.QGridLayout(self.interpretertab)
        self.gridLayout_9.setObjectName(_fromUtf8("gridLayout_9"))
        self.scrollInterpreter = QtGui.QScrollArea(self.interpretertab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollInterpreter.sizePolicy().hasHeightForWidth())
        self.scrollInterpreter.setSizePolicy(sizePolicy)
        self.scrollInterpreter.setMinimumSize(QtCore.QSize(200, 0))
        self.scrollInterpreter.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollInterpreter.setWidgetResizable(False)
        self.scrollInterpreter.setObjectName(_fromUtf8("scrollInterpreter"))
        self.interpreterWidget = QtGui.QWidget()
        self.interpreterWidget.setGeometry(QtCore.QRect(0, 0, 172, 460))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.interpreterWidget.sizePolicy().hasHeightForWidth())
        self.interpreterWidget.setSizePolicy(sizePolicy)
        self.interpreterWidget.setObjectName(_fromUtf8("interpreterWidget"))
        self.gridLayout_8 = QtGui.QGridLayout(self.interpreterWidget)
        self.gridLayout_8.setObjectName(_fromUtf8("gridLayout_8"))
        self.interpreterLayout = QtGui.QFormLayout()
        self.interpreterLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.interpreterLayout.setRowWrapPolicy(QtGui.QFormLayout.DontWrapRows)
        self.interpreterLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.interpreterLayout.setObjectName(_fromUtf8("interpreterLayout"))
        self.gridLayout_8.addLayout(self.interpreterLayout, 0, 0, 1, 1)
        self.scrollInterpreter.setWidget(self.interpreterWidget)
        self.gridLayout_9.addWidget(self.scrollInterpreter, 0, 0, 1, 1)
        self.tabWidget.addTab(self.interpretertab, _fromUtf8(""))
        self.verticalLayout_7.addWidget(self.tabWidget)
        self.verticalLayout_4.addWidget(self.frame_3)
        self.gridLayout_4.addLayout(self.verticalLayout_4, 1, 0, 1, 1)
        self.label_7 = QtGui.QLabel(self.frame)
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setMargin(5)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.gridLayout_4.addWidget(self.label_7, 0, 0, 1, 1)
        self.horizontalLayout_6.addWidget(self.frame)
        self.verticalLayout_10 = QtGui.QVBoxLayout()
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.frame_2 = QtGui.QFrame(self.centralwidget)
        self.frame_2.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_2.setObjectName(_fromUtf8("frame_2"))
        self.verticalLayout_13 = QtGui.QVBoxLayout(self.frame_2)
        self.verticalLayout_13.setObjectName(_fromUtf8("verticalLayout_13"))
        self.label_8 = QtGui.QLabel(self.frame_2)
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setMargin(5)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.verticalLayout_13.addWidget(self.label_8)
        self.tableWidget = MyDragTable(self.frame_2)
        self.tableWidget.setFrameShape(QtGui.QFrame.NoFrame)
        self.tableWidget.setFrameShadow(QtGui.QFrame.Raised)
        self.tableWidget.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.tableWidget.setAutoScroll(False)
        self.tableWidget.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.tableWidget.setTabKeyNavigation(False)
        self.tableWidget.setProperty("showDropIndicator", False)
        self.tableWidget.setDragEnabled(True)
        self.tableWidget.setDragDropOverwriteMode(False)
        self.tableWidget.setDragDropMode(QtGui.QAbstractItemView.DragOnly)
        self.tableWidget.setAlternatingRowColors(True)
        self.tableWidget.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
        self.tableWidget.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.tableWidget.setTextElideMode(QtCore.Qt.ElideNone)
        self.tableWidget.setShowGrid(True)
        self.tableWidget.setGridStyle(QtCore.Qt.NoPen)
        self.tableWidget.setWordWrap(False)
        self.tableWidget.setCornerButtonEnabled(False)
        self.tableWidget.setObjectName(_fromUtf8("tableWidget"))
        self.tableWidget.setColumnCount(8)
        self.tableWidget.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(3, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(4, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(5, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(6, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(7, item)
        self.tableWidget.horizontalHeader().setVisible(True)
        self.tableWidget.horizontalHeader().setCascadingSectionResizes(False)
        self.tableWidget.horizontalHeader().setHighlightSections(True)
        self.tableWidget.verticalHeader().setVisible(False)
        self.tableWidget.verticalHeader().setHighlightSections(False)
        self.verticalLayout_13.addWidget(self.tableWidget)
        self.musicframe = QtGui.QWidget(self.frame_2)
        self.musicframe.setObjectName(_fromUtf8("musicframe"))
        self.verticalLayout_6 = QtGui.QVBoxLayout(self.musicframe)
        self.verticalLayout_6.setMargin(0)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.musicdock = QtGui.QDockWidget(self.musicframe)
        self.musicdock.setFloating(False)
        self.musicdock.setFeatures(QtGui.QDockWidget.AllDockWidgetFeatures)
        self.musicdock.setAllowedAreas(QtCore.Qt.NoDockWidgetArea)
        self.musicdock.setObjectName(_fromUtf8("musicdock"))
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.musiclayout = QtGui.QVBoxLayout()
        self.musiclayout.setObjectName(_fromUtf8("musiclayout"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.timebar = MyProgressbar(self.dockWidgetContents)
        self.timebar.setMinimumSize(QtCore.QSize(0, 10))
        self.timebar.setMaximumSize(QtCore.QSize(16777215, 10))
        self.timebar.setProperty("value", 0)
        self.timebar.setTextVisible(False)
        self.timebar.setFormat(_fromUtf8(""))
        self.timebar.setObjectName(_fromUtf8("timebar"))
        self.horizontalLayout_3.addWidget(self.timebar)
        self.time = QtGui.QLabel(self.dockWidgetContents)
        self.time.setObjectName(_fromUtf8("time"))
        self.horizontalLayout_3.addWidget(self.time)
        self.length = QtGui.QLabel(self.dockWidgetContents)
        self.length.setObjectName(_fromUtf8("length"))
        self.horizontalLayout_3.addWidget(self.length)
        self.musiclayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.previousbutton = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.previousbutton.sizePolicy().hasHeightForWidth())
        self.previousbutton.setSizePolicy(sizePolicy)
        self.previousbutton.setText(_fromUtf8(""))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/previous.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.previousbutton.setIcon(icon)
        self.previousbutton.setIconSize(QtCore.QSize(30, 30))
        self.previousbutton.setFlat(True)
        self.previousbutton.setObjectName(_fromUtf8("previousbutton"))
        self.horizontalLayout_4.addWidget(self.previousbutton)
        self.playbutton_2 = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playbutton_2.sizePolicy().hasHeightForWidth())
        self.playbutton_2.setSizePolicy(sizePolicy)
        self.playbutton_2.setText(_fromUtf8(""))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/play.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.playbutton_2.setIcon(icon1)
        self.playbutton_2.setIconSize(QtCore.QSize(30, 30))
        self.playbutton_2.setFlat(True)
        self.playbutton_2.setObjectName(_fromUtf8("playbutton_2"))
        self.horizontalLayout_4.addWidget(self.playbutton_2)
        self.pausebutton = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pausebutton.sizePolicy().hasHeightForWidth())
        self.pausebutton.setSizePolicy(sizePolicy)
        self.pausebutton.setText(_fromUtf8(""))
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/pause.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pausebutton.setIcon(icon2)
        self.pausebutton.setIconSize(QtCore.QSize(30, 30))
        self.pausebutton.setFlat(True)
        self.pausebutton.setObjectName(_fromUtf8("pausebutton"))
        self.horizontalLayout_4.addWidget(self.pausebutton)
        self.nextbutton = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nextbutton.sizePolicy().hasHeightForWidth())
        self.nextbutton.setSizePolicy(sizePolicy)
        self.nextbutton.setText(_fromUtf8(""))
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/next.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.nextbutton.setIcon(icon3)
        self.nextbutton.setIconSize(QtCore.QSize(30, 30))
        self.nextbutton.setFlat(True)
        self.nextbutton.setObjectName(_fromUtf8("nextbutton"))
        self.horizontalLayout_4.addWidget(self.nextbutton)
        self.verticalLayout_8 = QtGui.QVBoxLayout()
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.volume = QtGui.QLabel(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.volume.sizePolicy().hasHeightForWidth())
        self.volume.setSizePolicy(sizePolicy)
        self.volume.setObjectName(_fromUtf8("volume"))
        self.verticalLayout_8.addWidget(self.volume)
        self.soundSlider = QtGui.QSlider(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.soundSlider.sizePolicy().hasHeightForWidth())
        self.soundSlider.setSizePolicy(sizePolicy)
        self.soundSlider.setMaximum(10)
        self.soundSlider.setProperty("value", 1)
        self.soundSlider.setOrientation(QtCore.Qt.Horizontal)
        self.soundSlider.setObjectName(_fromUtf8("soundSlider"))
        self.verticalLayout_8.addWidget(self.soundSlider)
        self.horizontalLayout_4.addLayout(self.verticalLayout_8)
        self.musiclayout.addLayout(self.horizontalLayout_4)
        self.gridLayout.addLayout(self.musiclayout, 0, 0, 1, 1)
        self.musicdock.setWidget(self.dockWidgetContents)
        self.verticalLayout_6.addWidget(self.musicdock)
        self.verticalLayout_13.addWidget(self.musicframe)
        self.verticalLayout_13.setStretch(0, 1)
        self.verticalLayout_13.setStretch(1, 100)
        self.verticalLayout_10.addWidget(self.frame_2)
        self.horizontalLayout_6.addLayout(self.verticalLayout_10)
        self.playlistTab = QtGui.QTabWidget(self.centralwidget)
        self.playlistTab.setObjectName(_fromUtf8("playlistTab"))
        self.playlistsearch = QtGui.QWidget()
        self.playlistsearch.setObjectName(_fromUtf8("playlistsearch"))
        self.gridLayout_10 = QtGui.QGridLayout(self.playlistsearch)
        self.gridLayout_10.setObjectName(_fromUtf8("gridLayout_10"))
        self.playlistTreeView = MyTreeView(self.playlistsearch)
        self.playlistTreeView.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.playlistTreeView.setProperty("showDropIndicator", False)
        self.playlistTreeView.setSelectionBehavior(QtGui.QAbstractItemView.SelectItems)
        self.playlistTreeView.setObjectName(_fromUtf8("playlistTreeView"))
        self.gridLayout_10.addWidget(self.playlistTreeView, 3, 0, 1, 1)
        self.horizontalLayout_8 = QtGui.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.playlistFolderLineEdit = QtGui.QLineEdit(self.playlistsearch)
        self.playlistFolderLineEdit.setText(_fromUtf8(""))
        self.playlistFolderLineEdit.setObjectName(_fromUtf8("playlistFolderLineEdit"))
        self.horizontalLayout_8.addWidget(self.playlistFolderLineEdit)
        self.playlistCreateFolderButton = QtGui.QPushButton(self.playlistsearch)
        self.playlistCreateFolderButton.setObjectName(_fromUtf8("playlistCreateFolderButton"))
        self.horizontalLayout_8.addWidget(self.playlistCreateFolderButton)
        self.gridLayout_10.addLayout(self.horizontalLayout_8, 0, 0, 1, 1)
        self.horizontalLayout_9 = QtGui.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.playlistSearchLineEdit = QtGui.QComboBox(self.playlistsearch)
        self.playlistSearchLineEdit.setEditable(True)
        self.playlistSearchLineEdit.setInsertPolicy(QtGui.QComboBox.InsertAfterCurrent)
        self.playlistSearchLineEdit.setDuplicatesEnabled(True)
        self.playlistSearchLineEdit.setFrame(True)
        self.playlistSearchLineEdit.setObjectName(_fromUtf8("playlistSearchLineEdit"))
        self.horizontalLayout_9.addWidget(self.playlistSearchLineEdit)
        self.playlistSearchButton = QtGui.QPushButton(self.playlistsearch)
        self.playlistSearchButton.setObjectName(_fromUtf8("playlistSearchButton"))
        self.horizontalLayout_9.addWidget(self.playlistSearchButton)
        self.horizontalLayout_9.setStretch(0, 2)
        self.horizontalLayout_9.setStretch(1, 1)
        self.gridLayout_10.addLayout(self.horizontalLayout_9, 4, 0, 1, 1)
        self.playlistTab.addTab(self.playlistsearch, _fromUtf8(""))
        self.playlistInfo = QtGui.QWidget()
        self.playlistInfo.setObjectName(_fromUtf8("playlistInfo"))
        self.verticalLayout_11 = QtGui.QVBoxLayout(self.playlistInfo)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.playlistLineEdit = QtGui.QLineEdit(self.playlistInfo)
        self.playlistLineEdit.setMouseTracking(False)
        self.playlistLineEdit.setAcceptDrops(False)
        self.playlistLineEdit.setFrame(False)
        self.playlistLineEdit.setEchoMode(QtGui.QLineEdit.Normal)
        self.playlistLineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.playlistLineEdit.setObjectName(_fromUtf8("playlistLineEdit"))
        self.verticalLayout_11.addWidget(self.playlistLineEdit)
        self.playlistWidget = MyDropTable(self.playlistInfo)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playlistWidget.sizePolicy().hasHeightForWidth())
        self.playlistWidget.setSizePolicy(sizePolicy)
        self.playlistWidget.setFrameShape(QtGui.QFrame.NoFrame)
        self.playlistWidget.setFrameShadow(QtGui.QFrame.Plain)
        self.playlistWidget.setLineWidth(0)
        self.playlistWidget.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.playlistWidget.setTabKeyNavigation(False)
        self.playlistWidget.setProperty("showDropIndicator", False)
        self.playlistWidget.setDragDropOverwriteMode(False)
        self.playlistWidget.setDragDropMode(QtGui.QAbstractItemView.DropOnly)
        self.playlistWidget.setDefaultDropAction(QtCore.Qt.CopyAction)
        self.playlistWidget.setAlternatingRowColors(True)
        self.playlistWidget.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.playlistWidget.setTextElideMode(QtCore.Qt.ElideNone)
        self.playlistWidget.setGridStyle(QtCore.Qt.NoPen)
        self.playlistWidget.setWordWrap(False)
        self.playlistWidget.setCornerButtonEnabled(False)
        self.playlistWidget.setObjectName(_fromUtf8("playlistWidget"))
        self.playlistWidget.setColumnCount(3)
        self.playlistWidget.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.playlistWidget.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.playlistWidget.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.playlistWidget.setHorizontalHeaderItem(2, item)
        self.playlistWidget.horizontalHeader().setHighlightSections(False)
        self.playlistWidget.verticalHeader().setVisible(False)
        self.playlistWidget.verticalHeader().setDefaultSectionSize(20)
        self.playlistWidget.verticalHeader().setHighlightSections(False)
        self.verticalLayout_11.addWidget(self.playlistWidget)
        self.playlistSaveButton = QtGui.QPushButton(self.playlistInfo)
        self.playlistSaveButton.setObjectName(_fromUtf8("playlistSaveButton"))
        self.verticalLayout_11.addWidget(self.playlistSaveButton)
        self.horizontalLayout_5 = QtGui.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.playallbutton = QtGui.QPushButton(self.playlistInfo)
        self.playallbutton.setObjectName(_fromUtf8("playallbutton"))
        self.horizontalLayout_5.addWidget(self.playallbutton)
        self.resetallbutton = QtGui.QPushButton(self.playlistInfo)
        self.resetallbutton.setObjectName(_fromUtf8("resetallbutton"))
        self.horizontalLayout_5.addWidget(self.resetallbutton)
        self.verticalLayout_11.addLayout(self.horizontalLayout_5)
        self.playbutton = QtGui.QPushButton(self.playlistInfo)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playbutton.sizePolicy().hasHeightForWidth())
        self.playbutton.setSizePolicy(sizePolicy)
        self.playbutton.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.playbutton.setObjectName(_fromUtf8("playbutton"))
        self.verticalLayout_11.addWidget(self.playbutton)
        self.playlistTab.addTab(self.playlistInfo, _fromUtf8(""))
        self.horizontalLayout_6.addWidget(self.playlistTab)
        self.horizontalLayout_6.setStretch(0, 1)
        self.horizontalLayout_6.setStretch(1, 5)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 898, 21))
        self.menuBar.setObjectName(_fromUtf8("menuBar"))
        self.menuDatei = QtGui.QMenu(self.menuBar)
        self.menuDatei.setObjectName(_fromUtf8("menuDatei"))
        self.menuInfo = QtGui.QMenu(self.menuBar)
        self.menuInfo.setObjectName(_fromUtf8("menuInfo"))
        self.menuSong = QtGui.QMenu(self.menuBar)
        self.menuSong.setObjectName(_fromUtf8("menuSong"))
        MainWindow.setMenuBar(self.menuBar)
        self.actionVerzeichnis_wechseln = QtGui.QAction(MainWindow)
        self.actionVerzeichnis_wechseln.setObjectName(_fromUtf8("actionVerzeichnis_wechseln"))
        self.actionBeenden = QtGui.QAction(MainWindow)
        self.actionBeenden.setObjectName(_fromUtf8("actionBeenden"))
        self.actionInfo = QtGui.QAction(MainWindow)
        self.actionInfo.setObjectName(_fromUtf8("actionInfo"))
        self.actionRefresh = QtGui.QAction(MainWindow)
        self.actionRefresh.setObjectName(_fromUtf8("actionRefresh"))
        self.actionEdit = QtGui.QAction(MainWindow)
        self.actionEdit.setObjectName(_fromUtf8("actionEdit"))
        self.menuDatei.addAction(self.actionRefresh)
        self.menuDatei.addAction(self.actionVerzeichnis_wechseln)
        self.menuDatei.addSeparator()
        self.menuDatei.addAction(self.actionBeenden)
        self.menuInfo.addAction(self.actionInfo)
        self.menuSong.addAction(self.actionEdit)
        self.menuBar.addAction(self.menuDatei.menuAction())
        self.menuBar.addAction(self.menuSong.menuAction())
        self.menuBar.addAction(self.menuInfo.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.playlistTab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "Music Manager", None))
        self.label_3.setText(_translate("MainWindow", "Title", None))
        self.label_2.setText(_translate("MainWindow", "Album", None))
        self.label.setText(_translate("MainWindow", "Interpreter", None))
        self.label_5.setText(_translate("MainWindow", "Comment", None))
        self.label_4.setText(_translate("MainWindow", "Rating", None))
        self.csCheckBox.setText(_translate("MainWindow", "CS", None))
        self.genreButton.setText(_translate("MainWindow", "Edit Genres", None))
        self.filterResetButton.setText(_translate("MainWindow", "Filter Reset", None))
        self.saveButton.setText(_translate("MainWindow", "Save", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.genretab), _translate("MainWindow", "Genres", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.albumtab), _translate("MainWindow", "Album", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.interpretertab), _translate("MainWindow", "Interpret", None))
        self.label_7.setText(_translate("MainWindow", "Edit", None))
        self.label_8.setText(_translate("MainWindow", "Current Directory", None))
        self.tableWidget.setSortingEnabled(True)
        item = self.tableWidget.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "hidden", None))
        item = self.tableWidget.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Name", None))
        item = self.tableWidget.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Title", None))
        item = self.tableWidget.horizontalHeaderItem(3)
        item.setText(_translate("MainWindow", "Album", None))
        item = self.tableWidget.horizontalHeaderItem(4)
        item.setText(_translate("MainWindow", "Interpreter", None))
        item = self.tableWidget.horizontalHeaderItem(5)
        item.setText(_translate("MainWindow", "Genres", None))
        item = self.tableWidget.horizontalHeaderItem(6)
        item.setText(_translate("MainWindow", "Times Played", None))
        item = self.tableWidget.horizontalHeaderItem(7)
        item.setText(_translate("MainWindow", "Rating", None))
        self.musicdock.setWindowTitle(_translate("MainWindow", "Music Player", None))
        self.time.setText(_translate("MainWindow", "00:00", None))
        self.length.setText(_translate("MainWindow", "00:00", None))
        self.volume.setText(_translate("MainWindow", "Volume", None))
        self.playlistFolderLineEdit.setPlaceholderText(_translate("MainWindow", "New subfolder name", None))
        self.playlistCreateFolderButton.setText(_translate("MainWindow", "Create Folder", None))
        self.playlistSearchButton.setText(_translate("MainWindow", "search", None))
        self.playlistTab.setTabText(self.playlistTab.indexOf(self.playlistsearch), _translate("MainWindow", "Playlists", None))
        self.playlistLineEdit.setPlaceholderText(_translate("MainWindow", "Please Insert a title", None))
        item = self.playlistWidget.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "path(HIDDEN)", None))
        item = self.playlistWidget.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Title", None))
        item = self.playlistWidget.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Length", None))
        self.playlistSaveButton.setText(_translate("MainWindow", "Save Playlist", None))
        self.playallbutton.setText(_translate("MainWindow", "Play Playlist", None))
        self.resetallbutton.setText(_translate("MainWindow", "Shuffle", None))
        self.playbutton.setText(_translate("MainWindow", "Playlist Random Play", None))
        self.playlistTab.setTabText(self.playlistTab.indexOf(self.playlistInfo), _translate("MainWindow", "Aktive Playlist", None))
        self.menuDatei.setTitle(_translate("MainWindow", "Data", None))
        self.menuInfo.setTitle(_translate("MainWindow", "Info", None))
        self.menuSong.setTitle(_translate("MainWindow", "Song", None))
        self.actionVerzeichnis_wechseln.setText(_translate("MainWindow", "Change Directory", None))
        self.actionBeenden.setText(_translate("MainWindow", "Exit", None))
        self.actionInfo.setText(_translate("MainWindow", "Info", None))
        self.actionRefresh.setText(_translate("MainWindow", "Refresh", None))
        self.actionEdit.setText(_translate("MainWindow", "Edit", None))

from myDropTable import MyDropTable
from myProgressbar import MyProgressbar
from myDragTable import MyDragTable
from mytreeview import MyTreeView
import resource_rc

if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    MainWindow = QtGui.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())

